Package: signatureSearchData
Title: Datasets for signatureSearch package
Description: CMAP/LINCS hdf5 databases and other annotations used for 
             signatureSearch software package.
Version: 1.27.0
Author: Yuzhu Duan <yduan004@ucr.edu>,
        Brendan Gongol <bgong001@ucr.edu>,
        Thomas Girke <thomas.girke@ucr.edu>
Maintainer: Brendan Gongol <bgong001@ucr.edu>
Depends: R (>= 3.6)
Imports: ExperimentHub, utils, affy, limma, Biobase, magrittr, dplyr,
        R.utils, stats, rhdf5
Suggests: knitr, rmarkdown
License: Artistic-2.0
biocViews: ExperimentHub, ExperimentData, ExpressionData
Encoding: UTF-8
VignetteBuilder: knitr
RoxygenNote: 7.1.2
git_url: https://git.bioconductor.org/packages/signatureSearchData
git_branch: devel
git_last_commit: a88e9f7
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 15:59:52 UTC; biocbuild
