# Generated by roxygen2: do not edit by hand

export(combineNormRes)
export(combineResults)
export(getCmapCEL)
export(inst_filter)
export(meanExpr)
export(normalizeCel)
export(probe2gene)
export(runLimma)
export(sampleList)
export(sig_filter)
importFrom(Biobase,ExpressionSet)
importFrom(R.utils,bunzip2)
importFrom(affy,ReadAffy)
importFrom(affy,exprs)
importFrom(affy,mas5)
importFrom(dplyr,bind_cols)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,lmFit)
importFrom(limma,makeContrasts)
importFrom(limma,topTable)
importFrom(magrittr,"%<>%")
importFrom(magrittr,"%>%")
importFrom(stats,model.matrix)
importFrom(utils,download.file)
importFrom(utils,read.delim)
importFrom(utils,unzip)
importFrom(utils,write.table)
